@@ -77,9 +77,8 @@ class HangmanTestCase(unittest.TestCase):
             with redirect_stdout(f):
                 self.game_2.check_guess('a')
             actual_value = f.getvalue()
-            actual_last = actual_value.split('\n')[-2]
-            expected = f"Good guess! a is in the word."
-            self.assertEqual(actual_last, expected, 'The check_guess method should print "Good guess! {guess} is in the word.". If you think you have defined the method correctly, make sure you are printing the correct string (same whitespace, capitalization, etc.)')
+            expected = "Good guess! a is in the word."
+            self.assertIn(expected, actual_value, 'The check_guess method should print "Good guess! {guess} is in the word.". If you think you have defined the method correctly, make sure you are printing the correct string (same whitespace, capitalization, etc.)')
             
         except TimeoutError:
             self.fail(' : The check_guess method is taking too long to run. Make sure you don\'t have an infinite loop in your code')
@@ -96,17 +95,15 @@ class HangmanTestCase(unittest.TestCase):
                 with patch('builtins.input', return_value='a'):
                     self.game.ask_for_input()
                 message = f.getvalue()
-            actual_last = message.split('\n')[-2]
-            self.assertEqual(actual_last, expected, 'The ask_for_input method should call the check_guess method with the user input as the guess parameter. If you think you have defined the method correctly, make sure you are calling the check_guess method with the correct parameter')
+            self.assertIn(expected, message, 'The ask_for_input method should call the check_guess method with the user input as the guess parameter. If you think you have defined the method correctly, make sure you are calling the check_guess method with the correct parameter, and that you are printing "Good guess! {guess} is in the word."')
             # Run the ask_for_input method and capture the output again to check for repeated guesses
             f = io.StringIO()
             with redirect_stdout(f):
                 with patch('builtins.input', side_effect=['a', 't']):
                     self.game.ask_for_input()
                 message = f.getvalue()
-            first_line = message.split('\n')[0]
             expected_first_line = 'You already tried that letter!'
-            self.assertEqual(first_line, expected_first_line, 'The ask_for_input method should print "You already tried that letter!" if the user tries a letter that has already been guessed. If you think you have defined the method correctly, make sure you are printing the correct string (same whitespace, capitalization, etc.)')
+            self.assertIn(expected_first_line, message, 'The ask_for_input method should print "You already tried that letter!" if the user tries a letter that has already been guessed. If you think you have defined the method correctly, make sure you are printing the correct string (same whitespace, capitalization, etc.)')
             # Check that the list_of_guesses attribute is updated after each guess
             with redirect_stdout(f):
                 with patch('builtins.input', return_value='w'):
@@ -151,12 +148,10 @@ class HangmanTestCase(unittest.TestCase):
                 message = f.getvalue()
             n_lines_message = len(message.split('\n'))
             self.assertGreaterEqual(n_lines_message, 3, 'Your Hangman class should print at least 2 different lines when the user guess a letter incorrectly. These are "Sorry, {letter} is not in the word.", and "You have {num_lives} lives left.". Additionally, make sure that you print them in the right order')
-            first_line = message.split('\n')[0]
-            second_line = message.split('\n')[1]
             expected_first_line = 'Sorry, z is not in the word.'
             expected_second_line = 'You have 4 lives left.'
-            self.assertEqual(first_line, expected_first_line, 'The first line printed when the user guesses a letter incorrectly should be "Sorry, {letter} is not in the word.". Make sure you are printing the correct string (same whitespace, capitalization, etc.)')
-            self.assertEqual(second_line, expected_second_line, 'The second line printed when the user guesses a letter incorrectly should be "You have {num_lives} lives left.". Make sure you are printing the correct string (same whitespace, capitalization, etc.)')
+            self.assertIn(expected_first_line, message, 'The first line printed when the user guesses a letter incorrectly should be "Sorry, {letter} is not in the word.". Make sure you are printing the correct string (same whitespace, capitalization, etc.)')
+            self.assertIn(expected_second_line, message, 'The second line printed when the user guesses a letter incorrectly should be "You have {num_lives} lives left.". Make sure you are printing the correct string (same whitespace, capitalization, etc.)')
             # Check that the num_lives attribute is updated after each incorrect guess
             self.assertEqual(self.game.num_lives, 4, 'The num_lives attribute should be decreased by 1 if the user guesses a letter that is not in the word')
             self.assertEqual(self.game.list_of_guesses, ['z'], 'The list_of_guesses attribute should be updated after each guess. Make sure you are appending the guess to the list_of_guesses attribute')
@@ -174,15 +169,8 @@ class HangmanTestCase(unittest.TestCase):
         self.assertIn('README.md', os.listdir('.'), 'You should have a README.md file in your project folder')
         with open('README.md', 'r') as f:
             readme = f.read()
-        self.assertGreater(len(readme), 1500, 'The README.md file should be at least 1000 characters long')
-        # nlp = spacy.load("en_core_web_md")
-        # tdata = str(pkgutil.get_data(__name__, "documentation.md"))
-        # # with open('documentation.md', 'r') as f:
-        # #     tdata = f.read()
-        # doc_1 = nlp(readme)
-        # doc_2 = nlp(tdata)
-        # self.assertLessEqual(doc_1.similarity(doc_2), 0.98, 'The README.md file is almost identical to the one provided in the template')
-
+        self.assertGreater(len(readme), 1500, 'The README.md file should be at least 1500 characters long')
+        
     def tearDown(self) -> None:
         self.game = self.Hangman(num_lives=5, word_list=['WatermelonBanana'])
 
