@@ -18,8 +18,9 @@ def get_errors_fails(report_path: str):
     if len(list_fails) > 1:
         list_fails = list_fails[1:]
 
-    fail_error = [fail.split('----------------------------------------------------------------------')[0]
-                for fail in list_fails]
+    # fail_error = [fail.split('----------------------------------------------------------------------')[0]
+    #             for fail in list_fails]
+    # print(fail_error)
     
     error_dict = {}
 
@@ -31,6 +32,11 @@ def get_errors_fails(report_path: str):
         elif error.startswith('\nFAIL'):
             fail_error = error.split('----------------------------------------------------------------------')[0].split('FAIL: ')[1].split(' (')[0]
             message = error.split('----------------------------------------------------------------------')[1].split(' : ')[1].strip()
+            if message.endswith("AssertionError:"):
+                try: 
+                    message = message.split("')")[0]
+                except:
+                    pass
             error_dict[fail_error] = message
 
     return error_dict
